@@ -76,6 +76,9 @@ fn cfg_test_table_header(unit_short_name: &str) -> String {
     )
 }
 
+#[cfg(test)]
+use crate::options::SortOrder;
+
 #[cfg(test)]
 use crate::util::units::Unit;
 
@@ -94,6 +97,7 @@ fn test_asciidoc_format_s() {
     let results = vec![
         BenchmarkResult {
             command: String::from("FOO=1 BAR=2 command | 1"),
+            command_with_unused_parameters: String::from("FOO=1 BAR=2 command | 1"),
             mean: 1.0,
             stddev: Some(2.0),
             median: 1.0,
@@ -112,6 +116,7 @@ fn test_asciidoc_format_s() {
         },
         BenchmarkResult {
             command: String::from("FOO=1 BAR=7 command | 2"),
+            command_with_unused_parameters: String::from("FOO=1 BAR=7 command | 2"),
             mean: 11.0,
             stddev: Some(12.0),
             median: 11.0,
@@ -130,8 +135,12 @@ fn test_asciidoc_format_s() {
         },
     ];
 
-    let actual =
-        String::from_utf8(exporter.serialize(&results, Some(Unit::Second)).unwrap()).unwrap();
+    let actual = String::from_utf8(
+        exporter
+            .serialize(&results, Some(Unit::Second), SortOrder::Command)
+            .unwrap(),
+    )
+    .unwrap();
     let expect = format!(
         "{}
 | `FOO=1 BAR=2 command \\| 1` 
@@ -163,6 +172,7 @@ fn test_asciidoc_format_ms() {
     let results = vec![
         BenchmarkResult {
             command: String::from("FOO=1 BAR=7 command | 2"),
+            command_with_unused_parameters: String::from("FOO=1 BAR=7 command | 2"),
             mean: 0.011,
             stddev: Some(0.012),
             median: 0.011,
@@ -181,6 +191,7 @@ fn test_asciidoc_format_ms() {
         },
         BenchmarkResult {
             command: String::from("FOO=1 BAR=2 command | 1"),
+            command_with_unused_parameters: String::from("FOO=1 BAR=2 command | 1"),
             mean: 1.0,
             stddev: Some(2.0),
             median: 1.0,
@@ -201,7 +212,7 @@ fn test_asciidoc_format_ms() {
 
     let actual = String::from_utf8(
         exporter
-            .serialize(&results, Some(Unit::MilliSecond))
+            .serialize(&results, Some(Unit::MilliSecond), SortOrder::Command)
             .unwrap(),
     )
     .unwrap();
